pub struct Window {
pub rows: Vec<TimelineRow>,
pub breaks: Vec<PlacedBreak>,
pub scopes: Vec<String>,
pub window_s: Option<f64>,
pub source: TimelineSource,
pub keys_evicted: u64,
}Expand description
A window and what was asked to get it — the input to timeline.
Fields
rows: Vec<TimelineRow>breaks: Vec<PlacedBreak>scopes: Vec<String>The selectors watched (O5).
window_s: Option<f64>source: TimelineSourcekeys_evicted: u64Keys the bounded statistics table retired during the window (O6).