pub struct Refusal {
pub storage: Option<String>,
pub volume: Option<String>,
pub key_expr: Option<String>,
pub reason: String,
pub cite: String,
}Expand description
One storage or volume the plan refused to emit.
Fields
storage: Option<String>volume: Option<String>key_expr: Option<String>The selector the refused storage would have taken — so --explain
can say “a refused storage would have taken this key”.
reason: Stringcite: StringTrait Implementations
impl StructuralPartialEq for Refusal